package com.mcwl.resource.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mcwl.common.constant.DictConstants;
import com.mcwl.common.core.domain.AjaxResult;
import com.mcwl.common.utils.StringUtils;
import com.mcwl.resource.domain.WorkFlow;
import com.mcwl.resource.domain.WorkFlowVersion;
import com.mcwl.resource.domain.request.RequestWorkFlow;
import com.mcwl.resource.domain.vo.PageVo;
import com.mcwl.resource.mapper.WorkFlowMapper;
import com.mcwl.resource.mapper.WorkFlowVersionMapper;
import com.mcwl.resource.service.ToActivityService;
import com.mcwl.resource.service.WorkFlowService;
import com.mcwl.web.controller.init.DictInit;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.Date;

/**
 * 工作流 业务实现层
 * @author DaiZibo
 * @date 2025/1/9
 * @apiNote
 */

@Slf4j
@Service
public class WorkFlowServiceImpl implements WorkFlowService {

    @Autowired
    private WorkFlowMapper flowMapper;

    @Autowired
    private WorkFlowVersionMapper workFlowVersionMapper;

    @Autowired
    private ToActivityService toActivityService;

    @Override
    public AjaxResult addWorkFlow(RequestWorkFlow requestWorkFlow) {

        //获取封面图
        String filePath = requestWorkFlow.getWorkFlowVersionList().get(0).getFilePath();

        String[] split = filePath.split(",");

        requestWorkFlow.getWorkFlow().setCoverPath(split[0]);
        requestWorkFlow.getWorkFlow().setCreateTime(new Date());
        //添加模型表数据
        flowMapper.insert(requestWorkFlow.getWorkFlow());

        log.info("获取到的入参:{}",requestWorkFlow.getWorkFlow());

        //批量添加版本
        workFlowVersionMapper.addWorkFlowVersion(requestWorkFlow.getWorkFlow(),requestWorkFlow.getWorkFlowVersionList());

        return AjaxResult.success("添加成功，等待审核");
    }

    @Override
    public void updateWorkFlow(RequestWorkFlow requestWorkFlow) {

        //修改工作流的信息
        if (requestWorkFlow.getWorkFlow().getId() != null){

            requestWorkFlow.getWorkFlow().setAuditStatus(3);
//            flowMapper.updateWorkFlow(requestWorkFlow.getWorkFlow());
            flowMapper.updateById(requestWorkFlow.getWorkFlow());
        }

        //修改工作流版本的信息
        if (requestWorkFlow.getWorkFlowVersionList().size() != 0){

            //批量修改
            for (WorkFlowVersion workFlowVersion : requestWorkFlow.getWorkFlowVersionList()) {
                workFlowVersion.setAuditStatus(3);
//                workFlowVersionMapper.updateWorkFlowVersion(workFlowVersion);
                workFlowVersionMapper.updateById(workFlowVersion);
            }

            WorkFlow workFlow = WorkFlow.builder().id(requestWorkFlow.getWorkFlowVersionList().get(0).getWorkFlowId())
                    .createTime(new Date()).build();
            //更新时间
            flowMapper.updateById(workFlow);

        }
    }

    @Override
    public void deleteWorkFlow(Long id) {

        WorkFlow workFlow = WorkFlow.builder().id(id)
                .delFlag(2).build();

        flowMapper.updateById(workFlow);
    }

    @Override
    public AjaxResult selectWorkFlow(PageVo pageVo) {

        Page<WorkFlow> page = new Page<>(pageVo.getPageNumber(), pageVo.getPageSize());

        LambdaQueryWrapper<WorkFlow> lambdaQueryWrapper = Wrappers.<WorkFlow>lambdaQuery()
                .like(StringUtils.isNotBlank(pageVo.getName()), WorkFlow::getWorkflowName, pageVo.getName())
                .eq(WorkFlow::getDelFlag,0);

        if (pageVo.getOrder() == 1){
            lambdaQueryWrapper.orderByDesc(WorkFlow::getUseNumber);
        }else {
            lambdaQueryWrapper.orderByDesc(WorkFlow::getId);
        }

        lambdaQueryWrapper.select(WorkFlow::getId, WorkFlow::getWorkflowName,WorkFlow::getCoverPath);

        return AjaxResult.success(flowMapper.selectPage(page,lambdaQueryWrapper));
    }

    @Override
    public AjaxResult selectWorkFlowById(Long id) {

        //查询详情
        WorkFlow workFlow = flowMapper.selectById(id);

        //翻译属性  垂类
        if (StringUtils.isNotEmpty(workFlow.getCategory())){
            workFlow.setCategory(DictInit.getDictValue(DictConstants.MODEL_CHILD_CATEGORY,workFlow.getCategory()));
        }

        //主体
        if (StringUtils.isNotEmpty(workFlow.getTheme())){
            ArrayList<String> strings = new ArrayList<>();
            String[] split = workFlow.getTheme().split(",");
            for (String s : split) {
                if (s != ""){
                    strings.add(DictInit.getDictValue(DictConstants.WORK_FLOW_THEME,workFlow.getCategory()));
                }
            }
            workFlow.setThemeList(strings);
        }

        //风格
        if (StringUtils.isNotEmpty(workFlow.getStyle())){
            ArrayList<String> strings = new ArrayList<>();
            String[] split = workFlow.getTheme().split(",");
            for (String s : split) {
                if (s != ""){
                    strings.add(DictInit.getDictValue(DictConstants.WORK_FLOW_STYLE,workFlow.getStyle()));
                }
            }
            workFlow.setStyleList(strings);
        }

        //功能
        if (StringUtils.isNotEmpty(workFlow.getFunctions())){
            workFlow.setCategory(DictInit.getDictValue(DictConstants.WORK_FLOW_FUNCTIONS,workFlow.getFunctions()));
        }

        //活动
        if (StringUtils.isNotEmpty(workFlow.getActivityParticipation())){
            workFlow.setActivityParticipation(toActivityService.getById(workFlow.getActivityParticipation()).getActivityName());
        }

        return AjaxResult.success(workFlow);
    }
}
